/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayModal from '@clayui/modal';
import PropTypes from 'prop-types';
import React from 'react';

import ImportPreviewModal from './ImportPreviewModal';
import ImportProcessModal from './ImportProcessModal';

const ImportModal = ({
	closeModal,
	dbFields,
	fieldsSelections,
	fileContent,
	fileFields,
	formDataQuerySelector,
	formSubmitURL,
	observer,
	portletNamespace,
	setFileContent,
	setStartImport,
	startImport,
}) => {
	const handleEditCell = (newValue, cellIndex, rowIndex) => {
		const newRow = fileContent[rowIndex];
		const newFileContent = fileContent;
		Object.entries(newRow).forEach(([key], index) => {
			if (cellIndex === index) {
				newRow[key] = newValue;
			}
		});

		newFileContent.splice(rowIndex, 1, newRow);
		setFileContent(newFileContent);
	};

	return (
		<ClayModal observer={observer} size={startImport ? 'lg' : 'md'}>
			{!startImport && (
				<ImportPreviewModal
					closeModal={closeModal}
					dbFields={dbFields}
					fieldsSelections={fieldsSelections}
					fileContent={fileContent}
					fileFields={fileFields}
					handleEditCell={handleEditCell}
					setStartImport={setStartImport}
				/>
			)}

			{startImport && (
				<ImportProcessModal
					closeModal={closeModal}
					formDataQuerySelector={formDataQuerySelector}
					formSubmitURL={formSubmitURL}
					namespace={portletNamespace}
					observer={observer}
				/>
			)}
		</ClayModal>
	);
};

ImportModal.propTypes = {
	closeModal: PropTypes.func.isRequired,
	formSubmitURL: PropTypes.string.isRequired,
	observer: PropTypes.object,
};

export default ImportModal;
