/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayButton from '@clayui/button';
import {useModal} from '@clayui/modal';
import {openToast} from 'frontend-js-web';
import PropTypes from 'prop-types';
import React, {useCallback, useState} from 'react';

import ImportModal from './ImportModal';

function ImportSubmit({
	disabled,
	evaluateForm,
	fieldsSelections,
	fileContent,
	fileFields,
	formDataQuerySelector,
	formImportURL,
	formIsValid,
	formIsVisible,
	portletNamespace,
	setFileContent,
}) {
	const [visibleModalPreview, setVisibleModalPreview] = useState(undefined);
	const [startImport, setStartImport] = useState(undefined);

	const {observer, onClose} = useModal({
		onClose: () => setVisibleModalPreview(false),
	});

	const showPreviewModal = useCallback(() => {
		evaluateForm(true);

		if (!formIsVisible) {
			openToast({
				message: Liferay.Language.get(
					'please-upload-a-file-and-select-the-required-columns-before-saving-a-template'
				),
				type: 'danger',
			});
		}

		if (formIsValid) {
			setVisibleModalPreview(true);
		}
	}, [evaluateForm, formIsValid, formIsVisible]);

	return (
		<span className="mr-3">
			<ClayButton
				disabled={disabled}
				displayType="primary"
				id={`${portletNamespace}-import-submit`}
				onClick={() => showPreviewModal()}
				type="button"
			>
				{Liferay.Language.get('next')}
			</ClayButton>

			{visibleModalPreview && (
				<ImportModal
					closeModal={onClose}
					fieldsSelections={fieldsSelections}
					fileContent={fileContent}
					fileFields={fileFields}
					formDataQuerySelector={formDataQuerySelector}
					formSubmitURL={formImportURL}
					namespace={portletNamespace}
					observer={observer}
					setFileContent={setFileContent}
					setStartImport={setStartImport}
					startImport={startImport}
				/>
			)}
		</span>
	);
}

ImportSubmit.propTypes = {
	formDataQuerySelector: PropTypes.string.isRequired,
	formImportURL: PropTypes.string.isRequired,
	portletNamespace: PropTypes.string.isRequired,
};

export default ImportSubmit;
